==> nextcloud-24.0.5.tgz: nextcloud/apps/text/l10n/br.js <==
OC.L10N.register(
    "text",
    {
    "Use current version" : "Implij stumm hiziv",
    "Use the saved version" : "Implij ",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Cheñchet eo bet an diel er maez eus an embanner. N'eo ket posuple lakaat pez a oa bet cheñchet.",
    "File could not be loaded. Please check your internet connection." : "N'eo ket bet karget ar restr. Gwiriit o genstagadenn  internet.",
    "Edit guest name" : "Embannañ anv an hini pedet",
    "Guest" : "Kouviad",
    "Save guest name" : "Enrollañ anv an hini pedet",
    "guest" : "kouviad",
    "Saving …" : "Orc'h enrolliñ",
    "Saved" : "Enrollet",
    "Last saved {lastSaved}" : "Enrolladen  divezhañ {lastSaved}",
    "Unsaved changes" : "Kemmoù n'int ket bet enrollet",
    "Link file" : "Liamm restr",
    "Select file to link to" : "Choaz ur restr da liammañ da",
    "Info" : "Titouroù",
    "Success" : "Graet",
    "Warning" : "Kemenadenn",
    "Command" : "Urzh",
    "Edit" : "Cheñch",
    "Enter your name so other users can see who is editing" : "Lakait o anv ma vo posuple d'an implijourien all gwellet piv a zo oc'h embannañ",
    "Insert an image" : "Lakaat ur skeudenn"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/text/l10n/br.js <==
OC.L10N.register(
    "text",
    {
    "Use current version" : "Implij stumm hiziv",
    "Use the saved version" : "Implij ",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Cheñchet eo bet an diel er maez eus an embanner. N'eo ket posuple lakaat pez a oa bet cheñchet.",
    "File could not be loaded. Please check your internet connection." : "N'eo ket bet karget ar restr. Gwiriit o genstagadenn  internet.",
    "Edit guest name" : "Embannañ anv an hini pedet",
    "Guest" : "Kouviad",
    "Save guest name" : "Enrollañ anv an hini pedet",
    "guest" : "kouviad",
    "Offline" : "Distaget",
    "Saving …" : "Orc'h enrolliñ",
    "Saved" : "Enrollet",
    "Unsaved changes" : "Kemmoù n'int ket bet enrollet",
    "Info" : "Titouroù",
    "Success" : "Graet",
    "Warning" : "Kemenadenn",
    "Command" : "Urzh",
    "Edit" : "Cheñch",
    "Last saved {lastSaved}" : "Enrolladen  divezhañ {lastSaved}",
    "Enter your name so other users can see who is editing" : "Lakait o anv ma vo posuple d'an implijourien all gwellet piv a zo oc'h embannañ",
    "Insert an image" : "Lakaat ur skeudenn",
    "Link file" : "Liamm restr",
    "Select file to link to" : "Choaz ur restr da liammañ da"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
